/*
 * Date: 2003-01-16
 *
 */

package tein.pt2.intro;

import java.util.StringTokenizer;

//Imports from java standard library.

/**
 * This class represents a phone book entry containing a name and a phone number.
 * Entries are comparable since they implement the Comparable interface specified
 * in the java.util package.
 *
 * Inheritance in java is simpler than in C++, mostly due to the disallowance of
 * multiple inheritance, MI. Instead of MI it is possible to implement several
 * interfaces. An interface is like an abstract class but without any implementation,
 * constructors or variables.
 */
public class MWPhoneBookEntry implements Comparable {

    // Constants

    /** The delimiter of data in an entry in the phone booke file. */
      public static final String DELIMITER = ";";

    // Class Variables
    // Instance Variables

    /** The name of the person this entry is for. */
    private String iName;

    /** The phone number of the person. */
    private String iPhoneNumber;
    /**
     * Constructor taking a name and phone number.
     * @param name
     *        The name of the person to store the phone number for.
     * @param phoneNumber
     *        The phone number of the person.
     */
    public MWPhoneBookEntry( String name, String phoneNumber) {
	iName = name;
	iPhoneNumber = phoneNumber;
    }


    /**
     * Get-method for the name.
     * @return The name of the person this entry is for.
     */
    public String getName() {
	return iName;
    }

    /**
     * Get-method for the phone number of this entry.
     * @return The phone number for this entry.
     */
    public String getPhoneNumber() {
	return iPhoneNumber;
    }

    /**
     * This static method takes a string representation of a
     * phone book entry and parses it into a new entry.
     * @param input
     * @return A new MWPhoneBookEntry, parsed from the argument string.
     */
    public static MWPhoneBookEntry fromString(String input) {
        MWPhoneBookEntry answer = null;
        StringTokenizer tokenizer = new StringTokenizer(input, DELIMITER);

        if( tokenizer.countTokens() == 2) {
            answer = new MWPhoneBookEntry( tokenizer.nextToken(), tokenizer.nextToken());
        }
        else {
            System.out.println("MWPhoneBookEntry.fromString/1: Faulty line in input file: ["+input+"]");
        }
        return answer;
    }

    /**
     * Method for writing a parsable string of this entry.
     * The method uses a StringBuffer rather than the "+"
     * operators for strings. The reason is that using
     * StringBuffer is usually faster.
     * @return A string representing the entry.
     */
    public String toString() {
        StringBuffer buffer = new StringBuffer(512);
        buffer.append(iName).append(DELIMITER).append(iPhoneNumber);
        return buffer.toString();
    }

    /**
     * This method is specified by the Comparable interface.
     * Compares an entry with the called entry to determine
     * in which order they should be.
     * First compared is the name, if the names are the same the phone
     * number is compared. If both names and numbers are equal,
     * the method returns, indicating equality.
     * @param obj The entry to compare with.
     * @return 0 if  names and numbers are equal. a number greater than 0 if th entry comes before
     *         the supplied entry, and less than 0 if the entry if is after the argument entry.
     */
    public int compareTo(Object obj) {
        MWPhoneBookEntry entry = (MWPhoneBookEntry) obj;
        int result = iName.compareToIgnoreCase(entry.getName());

        if( result == 0) {
            result = iPhoneNumber.compareToIgnoreCase( entry.getPhoneNumber());
        }
        return result;
    }
}
